@@ -6,6 +6,8 @@ class Character(models.Model):
     name = models.CharField(max_length=80, unique=True)
     firstname = models.CharField(max_length=80,blank=True,null=True)
     lastname = models.CharField(max_length=80,blank=True,null=True)
+    sortorder = models.IntegerField(default=999)
+    visible = models.BooleanField(default=True)
     books = models.ManyToManyField(Book, blank=True,null=True, related_name='characters')
     bioshort = models.CharField(max_length=500,blank=True,null=True)
     biolong = models.TextField(blank=True,null=True)
